

set -ex



pytest -vv
test ! -f /var/folders/nz/j6p8yfhx1mv_0grj5xl4650h0000gp/T/abs_ackrku03fz/croot/conda-standalone_1711655499376/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeho/bin/codesign
exit 0
